pub struct TransactionIndexerEvent {
pub leaves: Vec<[u8; 32]>,
pub public_amount_spl: [u8; 32],
pub public_amount_sol: [u8; 32],
pub relayer_fee: u64,
pub encrypted_utxos: Vec<u8>,
pub nullifiers: Vec<[u8; 32]>,
pub first_leaf_index: u64,
pub message: Vec<u8>,
}Fields
leaves: Vec<[u8; 32]>public_amount_spl: [u8; 32]public_amount_sol: [u8; 32]relayer_fee: u64encrypted_utxos: Vec<u8>nullifiers: Vec<[u8; 32]>first_leaf_index: u64message: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for TransactionIndexerEventwhere
Vec<[u8; 32]>: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u64: BorshDeserialize,
Vec<u8>: BorshDeserialize,
impl BorshDeserialize for TransactionIndexerEventwhere
Vec<[u8; 32]>: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u64: BorshDeserialize,
Vec<u8>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TransactionIndexerEventwhere
Vec<[u8; 32]>: BorshSerialize,
[u8; 32]: BorshSerialize,
u64: BorshSerialize,
Vec<u8>: BorshSerialize,
impl BorshSerialize for TransactionIndexerEventwhere
Vec<[u8; 32]>: BorshSerialize,
[u8; 32]: BorshSerialize,
u64: BorshSerialize,
Vec<u8>: BorshSerialize,
Sourceimpl Clone for TransactionIndexerEvent
impl Clone for TransactionIndexerEvent
Sourcefn clone(&self) -> TransactionIndexerEvent
fn clone(&self) -> TransactionIndexerEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TransactionIndexerEvent
impl RefUnwindSafe for TransactionIndexerEvent
impl Send for TransactionIndexerEvent
impl Sync for TransactionIndexerEvent
impl Unpin for TransactionIndexerEvent
impl UnsafeUnpin for TransactionIndexerEvent
impl UnwindSafe for TransactionIndexerEvent